<?php
namespace Elementor;

class Slider extends Widget_Base {
	
	public function get_name() {
		return 'slider';
	}
	
	public function get_title() {
		return __( 'Slider', 'dina-kala' );
	}
	
	public function get_icon() {
		return 'fal fa-images';
	}
	
	public function get_categories() {
		return [ 'dina-kala' ];
	}
	
	protected function _register_controls() {

		$this->start_controls_section(
			'section_title',
			[
				'label' => __( 'Slider', 'dina-kala' ),
			]
		);
		
		$slider = new Repeater();

		$slider->add_control(
			'slide_title', [
				'label' => __( 'Slide title', 'dina-kala' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$slider->add_control(
			'slide_link',
			[
				'label' => __( 'Slide link', 'dina-kala' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'dina-kala' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
        );
        
        $slider->add_control(
			'slide_image',
			[
				'label' => __( 'Choose Image', 'dina-kala' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'slides',
			[
				'label' => __( 'Sliders', 'dina-kala' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $slider->get_controls(),
				'default' => [
					[
						'slide_title' => __( 'Slide title', 'dina-kala' ),
						'slide_link' => __( 'https://your-link.com', 'dina-kala' ),
					],
				],
				'title_field' => '{{{ slide_title }}}',
			]
		);

		$this->add_control(
			'show_arrows',
			[
				'label' => __( 'Show arrows', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'auto_play',
			[
				'label' => __( 'Auto play', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_dots',
			[
				'label' => __( 'Show navigation\'s dots', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_titles',
			[
				'label' => __( 'Show slide titles instead of navigation points', 'dina-kala' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'On', 'dina-kala' ),
				'label_off' => __( 'Off', 'dina-kala' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'time',
			[
				'label' => __( 'Auto play speed(ms)', 'dina-kala' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 1000,
				'max' => 20000,
				'step' => 1000,
				'default' => 8000,
			]
		);
        
		$this->end_controls_section();
	}
	
	protected function render() {

        $settings = $this->get_settings_for_display();
        
		?>
		<!-- start slider -->
		<div class="scon shadow-box">
		<div class="slider-con owl-carousel" <?php if ( 'yes' === $settings['show_titles'] ) { echo 'data-itemdotsc="#slider-title"'; } ?> <?php if ( 'yes' === $settings['show_arrows'] ) { echo 'data-itemnavs="true"'; } else { echo 'data-itemnavs="false"'; } ?> <?php if ( 'yes' === $settings['show_dots'] ) { echo 'data-itemdots="true"'; } else { echo 'data-itemdots="false"'; } ?> <?php if ( 'yes' === $settings['auto_play'] ) { echo 'data-itemplay="true"'; } else { echo 'data-itemplay="false"'; } ?> data-itemtime="<?php echo $settings['time']; ?>">
			<?php if ( $settings['slides'] ) {
				foreach (  $settings['slides'] as $item ) {
				$target = $item['slide_link']['is_external'] ? ' target="_blank"' : '';
				$nofollow = $item['slide_link']['nofollow'] ? ' rel="nofollow"' : ''; ?>
			<div class="item">
			<?php if(!empty($item['slide_link']['url'])) { ?>
				<a href="<?php echo $item['slide_link']['url']; ?>" title="<?php echo $item['slide_title']; ?>"<?php if(!empty($target)) { echo $target;} ?> <?php if(!empty($nofollow)) { echo $nofollow;} ?>>
			<?php } ?>
					<img src="<?php echo $item['slide_image']['url']; ?>" alt="<?php echo $item['slide_title']; ?>" class="slider-img">
			<?php if(!empty($item['slide_link']['url'])) { ?>
				</a>
			<?php } ?>
			</div>
			<?php } } ?>
		</div>
		<?php if ( 'yes' === $settings['show_titles'] ) { ?>
		<div class="col-12 slider-title-outer">
			<ul id="slider-title" class="">
				<?php if ( $settings['slides'] ) {
				foreach (  $settings['slides'] as $item ) { ?>
				<li>
					<span class="slide-title"><?php echo $item['slide_title']; ?></span>
				</li>
				<?php } } ?>
			</ul>
		</div>
		<?php } ?>
		</div>
		<!-- end slider -->
         <?php

	}


}